@@ -106,15 +106,12 @@ select_server (CORBA_Environment *ev)
 static void
 speech_interrupt_test (GNOME_Speech_Speaker s)
 {
-	Callback *cb = callback_new ();
-	BonoboObject *o = BONOBO_OBJECT (cb);
 	gint i;
 	gint delay;
 	CORBA_Environment ev;
 	
 	CORBA_exception_init (&ev);
-	GNOME_Speech_Speaker_registerSpeechCallback (s,
-						     bonobo_object_corba_objref (o), &ev);
+
 	for (i = 0; i < 100; i++) {
 		gchar *str = g_strdup_printf ("Test %d\n", i);
 		GNOME_Speech_Speaker_say (s, str, &ev);
@@ -124,7 +121,6 @@ speech_interrupt_test (GNOME_Speech_Speaker s)
 		GNOME_Speech_Speaker_stop (s, &ev);
 		fprintf (stderr, "%d\r", i);
 	}
-	bonobo_object_unref (BONOBO_OBJECT(cb));
 	CORBA_exception_free (&ev);
 }
 
